diff --git a/ElementX.xcodeproj/project.pbxproj b/ElementX.xcodeproj/project.pbxproj
index 193599f79..93a16067c 100644
--- a/ElementX.xcodeproj/project.pbxproj
+++ b/ElementX.xcodeproj/project.pbxproj
@@ -1426,7 +1426,7 @@
FB595EC9C00AB32F39034055 /* SceneDelegate.swift in Sources */ = {isa = PBXBuildFile; fileRef = 5A37E2FACFD041CE466223CD /* SceneDelegate.swift */; };
FBD402E3170EB1ED0D1AA672 /* EncryptionKeyProvider.swift in Sources */ = {isa = PBXBuildFile; fileRef = 2355398E4A55DA5A89128AD1 /* EncryptionKeyProvider.swift */; };
FBF09B6C900415800DDF2A21 /* EmojiProvider.swift in Sources */ = {isa = PBXBuildFile; fileRef = 6C113E0CB7E15E9765B1817A /* EmojiProvider.swift */; };
- FC10228E73323BDC09526F97 /* Mapbox in Frameworks */ = {isa = PBXBuildFile; productRef = C1BF15833233CD3BDB7E2B1D /* Mapbox */; };
+ FC10228E73323BDC09526F97 /* MapLibre in Frameworks */ = {isa = PBXBuildFile; productRef = ED146E565C4CB792FF2F37EA /* MapLibre */; };
FC31493979ED1FDF7D5EA3F9 /* KeychainController.swift in Sources */ = {isa = PBXBuildFile; fileRef = E36CB905A2B9EC2C92A2DA7C /* KeychainController.swift */; };
FCD3F2B82CAB29A07887A127 /* Kingfisher in Frameworks */ = {isa = PBXBuildFile; productRef = DE8DC9B3FBA402117DC4C49F /* Kingfisher */; };
FCF95603F1D056B1B106A415 /* AdvancedSettingsScreenViewModelProtocol.swift in Sources */ = {isa = PBXBuildFile; fileRef = 83E2B20431F890ED64255CA1 /* AdvancedSettingsScreenViewModelProtocol.swift */; };
@@ -3010,7 +3010,7 @@
6298AB0906DDD3525CD78C6B /* KZFileWatchers in Frameworks */,
407DCE030E0F9B7C9861D38A /* LoremSwiftum in Frameworks */,
8F2FAA98457750D9D664136F /* LRUCache in Frameworks */,
- FC10228E73323BDC09526F97 /* Mapbox in Frameworks */,
+ FC10228E73323BDC09526F97 /* MapLibre in Frameworks */,
EAC6FE2CD4F50A43068ADCD8 /* PostHog in Frameworks */,
754602A7B2AAD443C4228ED4 /* SwiftState in Frameworks */,
B0CB16349B96262AA65A04AF /* GZIP in Frameworks */,
@@ -6961,7 +6961,7 @@
81DB3AB6CE996AB3954F4F03 /* KZFileWatchers */,
1A6B622CCFDEFB92D9CF1CA5 /* LoremSwiftum */,
1081D3630AAD3ACEDDEC3A98 /* LRUCache */,
- C1BF15833233CD3BDB7E2B1D /* Mapbox */,
+ ED146E565C4CB792FF2F37EA /* MapLibre */,
4278261E147DB2DE5CFB7FC5 /* PostHog */,
9573B94B1C86C6DF751AF3FD /* SwiftState */,
997C7385E1A07E061D7E2100 /* GZIP */,
@@ -9679,7 +9679,7 @@
repositoryURL = "https://github.com/maplibre/maplibre-gl-native-distribution";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 5.13.0;
+ minimumVersion = 6.22.1;
};
};
395DE6AE429B7ACC7C7FE31D /* XCRemoteSwiftPackageReference "KZFileWatchers" */ = {
@@ -9695,7 +9695,7 @@
repositoryURL = "https://github.com/apple/swift-async-algorithms";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 1.0.0;
+ minimumVersion = 1.1.1;
};
};
4BDA7F6042968E8422470F3F /* XCRemoteSwiftPackageReference "LoremSwiftum" */ = {
@@ -9703,7 +9703,7 @@
repositoryURL = "https://github.com/lukaskubanek/LoremSwiftum";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 2.2.1;
+ minimumVersion = 2.2.3;
};
};
4C34425923978C97409A3EF2 /* XCRemoteSwiftPackageReference "DSWaveformImage" */ = {
@@ -9711,7 +9711,7 @@
repositoryURL = "https://github.com/dmrschmidt/DSWaveformImage";
requirement = {
kind = exactVersion;
- version = 14.1.1;
+ version = 14.2.2;
};
};
61916C63E3F5BD900F08DA0C /* XCRemoteSwiftPackageReference "KeychainAccess" */ = {
@@ -9759,7 +9759,7 @@
repositoryURL = "https://github.com/element-hq/element-call-swift";
requirement = {
kind = exactVersion;
- version = "0.16.0-rc.4";
+ version = 0.16.3;
};
};
821C67C9A7F8CC3FD41B28B4 /* XCRemoteSwiftPackageReference "emojibase-bindings" */ = {
@@ -9767,7 +9767,7 @@
repositoryURL = "https://github.com/matrix-org/emojibase-bindings";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 1.4.2;
+ minimumVersion = 1.5.0;
};
};
869B65C34E469FC879A9F116 /* XCRemoteSwiftPackageReference "swift-clocks" */ = {
@@ -9783,7 +9783,7 @@
repositoryURL = "https://github.com/PostHog/posthog-ios";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 3.27.0;
+ minimumVersion = 3.37.1;
};
};
A08925A9D5E3770DEB9D8509 /* XCRemoteSwiftPackageReference "sentry-cocoa" */ = {
@@ -9791,7 +9791,7 @@
repositoryURL = "https://github.com/getsentry/sentry-cocoa";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 8.52.1;
+ minimumVersion = 9.1.0;
};
};
AB8E808A59756170682BEC20 /* XCRemoteSwiftPackageReference "SwiftSoup" */ = {
@@ -9799,7 +9799,7 @@
repositoryURL = "https://github.com/scinfu/SwiftSoup.git";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 2.8.8;
+ minimumVersion = 2.11.2;
};
};
AC3475112CA40C2C6E78D1EB /* XCRemoteSwiftPackageReference "matrix-analytics-events" */ = {
@@ -9807,7 +9807,7 @@
repositoryURL = "https://github.com/matrix-org/matrix-analytics-events";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 0.29.2;
+ minimumVersion = 0.30.0;
};
};
CCD235515AFCEE6D2005B705 /* XCRemoteSwiftPackageReference "LRUCache" */ = {
@@ -9815,7 +9815,7 @@
repositoryURL = "https://github.com/nicklockwood/LRUCache";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 1.0.4;
+ minimumVersion = 1.2.0;
};
};
D283517192CAC3E2E6920765 /* XCRemoteSwiftPackageReference "Kingfisher" */ = {
@@ -9823,7 +9823,7 @@
repositoryURL = "https://github.com/onevcat/Kingfisher";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 8.3.2;
+ minimumVersion = 8.6.2;
};
};
D5F7D47BBAAE0CF1DDEB3034 /* XCRemoteSwiftPackageReference "DeviceKit" */ = {
@@ -9831,7 +9831,7 @@
repositoryURL = "https://github.com/devicekit/DeviceKit";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 5.6.0;
+ minimumVersion = 5.7.0;
};
};
E025F19D013D9BA6C58B37F4 /* XCRemoteSwiftPackageReference "swift-algorithms" */ = {
@@ -9879,7 +9879,7 @@
repositoryURL = "https://github.com/apple/swift-collections";
requirement = {
kind = upToNextMinorVersion;
- minimumVersion = 1.2.0;
+ minimumVersion = 1.3.0;
};
};
/* End XCRemoteSwiftPackageReference section */
@@ -10153,11 +10153,6 @@
package = 6FC4820D8D4559CEECA064D7 /* XCRemoteSwiftPackageReference "matrix-rust-components-swift" */;
productName = MatrixRustSDK;
};
- C1BF15833233CD3BDB7E2B1D /* Mapbox */ = {
- isa = XCSwiftPackageProductDependency;
- package = 0CBF57301AA172C21F76CE86 /* XCRemoteSwiftPackageReference "maplibre-gl-native-distribution" */;
- productName = Mapbox;
- };
C2C69B8BA5A9702E7A8BC08F /* MatrixRustSDK */ = {
isa = XCSwiftPackageProductDependency;
package = 6FC4820D8D4559CEECA064D7 /* XCRemoteSwiftPackageReference "matrix-rust-components-swift" */;
@@ -10207,6 +10202,11 @@
package = D283517192CAC3E2E6920765 /* XCRemoteSwiftPackageReference "Kingfisher" */;
productName = Kingfisher;
};
+ ED146E565C4CB792FF2F37EA /* MapLibre */ = {
+ isa = XCSwiftPackageProductDependency;
+ package = 0CBF57301AA172C21F76CE86 /* XCRemoteSwiftPackageReference "maplibre-gl-native-distribution" */;
+ productName = MapLibre;
+ };
EDFB92E97D9AC4BA8540C18C /* SwiftSoup */ = {
isa = XCSwiftPackageProductDependency;
package = AB8E808A59756170682BEC20 /* XCRemoteSwiftPackageReference "SwiftSoup" */;
diff --git a/ElementX.xcodeproj/project.xcworkspace/xcshareddata/swiftpm/Package.resolved b/ElementX.xcodeproj/project.xcworkspace/xcshareddata/swiftpm/Package.resolved
index b5dcb6db9..eccb161ee 100644
--- a/ElementX.xcodeproj/project.xcworkspace/xcshareddata/swiftpm/Package.resolved
+++ b/ElementX.xcodeproj/project.xcworkspace/xcshareddata/swiftpm/Package.resolved
@@ -14,8 +14,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/devicekit/DeviceKit",
"state" : {
- "revision" : "513b9d7e7a1bd46504a1009bbab943b75ce2f195",
- "version" : "5.6.0"
+ "revision" : "581df61650bc457ec00373a592a84be3e7468eb1",
+ "version" : "5.7.0"
}
},
{
@@ -23,8 +23,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/dmrschmidt/DSWaveformImage",
"state" : {
- "revision" : "6074c2334a5a34afaa8394df853c8ceb026ad137",
- "version" : "14.1.1"
+ "revision" : "4c56578ee10128ee2b2c04c9c5aa73812de722db",
+ "version" : "14.2.2"
}
},
{
@@ -59,8 +59,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/element-hq/element-call-swift",
"state" : {
- "revision" : "3e2571a11f611761114038225ef368dd9ac83805",
- "version" : "0.16.0-rc.4"
+ "revision" : "6fd94d696cc2118fa2180d2e3216020cfa83d3cc",
+ "version" : "0.16.3"
}
},
{
@@ -68,8 +68,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/matrix-org/emojibase-bindings",
"state" : {
- "revision" : "259aa23c03401fc77b2d8c51219993235a1806c9",
- "version" : "1.4.2"
+ "revision" : "d1ed54c3bf63caa8fb48a30e16e465ac148f26f6",
+ "version" : "1.5.0"
}
},
{
@@ -95,8 +95,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/onevcat/Kingfisher",
"state" : {
- "revision" : "010a06c4387cea2d13606222b6c08e0454e6dd2d",
- "version" : "8.3.3"
+ "revision" : "d30a5fad881137e2267f96a8e3fc35c58999bb94",
+ "version" : "8.6.2"
}
},
{
@@ -113,8 +113,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/lukaskubanek/LoremSwiftum",
"state" : {
- "revision" : "8942e732e50458cde5dccf9996afa16f29372853",
- "version" : "2.2.2"
+ "revision" : "a293c2339552c8cfb715e7f76c511feec02782ad",
+ "version" : "2.2.3"
}
},
{
@@ -122,8 +122,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/nicklockwood/LRUCache",
"state" : {
- "revision" : "6d2b5246c9c98dcd498552bb22f08d55b12a8371",
- "version" : "1.0.4"
+ "revision" : "0d91406ecd4d6c1c56275866f00508d9aeacc92a",
+ "version" : "1.2.0"
}
},
{
@@ -131,8 +131,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/maplibre/maplibre-gl-native-distribution",
"state" : {
- "revision" : "ffda61e298c1490d4860d5184e80d618aaadc089",
- "version" : "5.13.0"
+ "revision" : "fa12216f30833c2b4d897714f7c1ca2f5608f685",
+ "version" : "6.22.1"
}
},
{
@@ -140,8 +140,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/matrix-org/matrix-analytics-events",
"state" : {
- "revision" : "c547e749acb8fc7a8b11eef5022f37854e4bf455",
- "version" : "0.29.2"
+ "revision" : "cb37ee194ba298695abf10e982ef603eee06add9",
+ "version" : "0.30.0"
}
},
{
@@ -185,8 +185,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/PostHog/posthog-ios",
"state" : {
- "revision" : "95bba2b66874dc01e624da6610dd8732817165c8",
- "version" : "3.27.0"
+ "revision" : "3f80c969c17c7fa32518feb66f3eed63613639d0",
+ "version" : "3.37.1"
}
},
{
@@ -194,8 +194,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/getsentry/sentry-cocoa",
"state" : {
- "revision" : "930b78a63f47549c81e6e63c9172584f7d3dfdd6",
- "version" : "8.52.1"
+ "revision" : "0041fe6374a0557747d3c7f19888510a30684dfa",
+ "version" : "9.1.0"
}
},
{
@@ -221,8 +221,17 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/apple/swift-async-algorithms",
"state" : {
- "revision" : "042e1c4d9d19748c9c228f8d4ebc97bb1e339b0b",
- "version" : "1.0.4"
+ "revision" : "6c050d5ef8e1aa6342528460db614e9770d7f804",
+ "version" : "1.1.1"
+ }
+ },
+ {
+ "identity" : "swift-atomics",
+ "kind" : "remoteSourceControl",
+ "location" : "https://github.com/apple/swift-atomics.git",
+ "state" : {
+ "revision" : "b601256eab081c0f92f059e12818ac1d4f178ff7",
+ "version" : "1.3.0"
}
},
{
@@ -239,8 +248,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/apple/swift-collections",
"state" : {
- "revision" : "c1805596154bb3a265fd91b8ac0c4433b4348fb0",
- "version" : "1.2.0"
+ "revision" : "7b847a3b7008b2dc2f47ca3110d8c782fb2e5c7e",
+ "version" : "1.3.0"
}
},
{
@@ -264,10 +273,10 @@
{
"identity" : "swift-numerics",
"kind" : "remoteSourceControl",
- "location" : "https://github.com/apple/swift-numerics",
+ "location" : "https://github.com/apple/swift-numerics.git",
"state" : {
- "revision" : "0a5bc04095a675662cf24757cc0640aa2204253b",
- "version" : "1.0.2"
+ "revision" : "0c0290ff6b24942dadb83a929ffaaa1481df04a2",
+ "version" : "1.1.1"
}
},
{
@@ -284,8 +293,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/pointfreeco/swift-snapshot-testing",
"state" : {
- "revision" : "1be8144023c367c5de701a6313ed29a3a10bf59b",
- "version" : "1.18.3"
+ "revision" : "a8b7c5e0ed33d8ab8887d1654d9b59f2cbad529b",
+ "version" : "1.18.7"
}
},
{
@@ -293,8 +302,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/swiftlang/swift-syntax",
"state" : {
- "revision" : "74203046135342e4a4a627476dd6caf8b28fe11b",
- "version" : "509.0.0"
+ "revision" : "4799286537280063c85a32f09884cfbca301b1a1",
+ "version" : "602.0.0"
}
},
{
@@ -302,8 +311,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/scinfu/SwiftSoup.git",
"state" : {
- "revision" : "aa85ee96017a730031bafe411cde24a08a17a9c9",
- "version" : "2.8.8"
+ "revision" : "d86f244ed497d48012782e2f59c985a55e77b3f5",
+ "version" : "2.11.3"
}
},
{
@@ -338,8 +347,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/pointfreeco/xctest-dynamic-overlay",
"state" : {
- "revision" : "39de59b2d47f7ef3ca88a039dff3084688fe27f4",
- "version" : "1.5.2"
+ "revision" : "34e463e98ab8541c604af706c99bed7160f5ec70",
+ "version" : "1.8.1"
}
}
],
diff --git a/ElementX/Sources/Application/AppCoordinator.swift b/ElementX/Sources/Application/AppCoordinator.swift
index 88085cfff..362399af2 100644
--- a/ElementX/Sources/Application/AppCoordinator.swift
+++ b/ElementX/Sources/Application/AppCoordinator.swift
@@ -980,11 +980,11 @@ class AppCoordinator: AppCoordinatorProtocol, AuthenticationFlowCoordinatorDeleg
if AppSettings.isDevelopmentBuild {
options.sampleRate = 1.0
options.tracesSampleRate = 1.0
- options.profilesSampleRate = 1.0
+ options.configureProfiling = { $0.sessionSampleRate = 1.0 }
} else {
options.sampleRate = 0.5
options.tracesSampleRate = 0.5
- options.profilesSampleRate = 0.5
+ options.configureProfiling = { $0.sessionSampleRate = 1.0 }
}
// This callback is only executed once during the entire run of the program to avoid
diff --git a/ElementX/Sources/Other/MapLibre/LocationAnnotation.swift b/ElementX/Sources/Other/MapLibre/LocationAnnotation.swift
index 9ea717a72..2e505eb55 100644
--- a/ElementX/Sources/Other/MapLibre/LocationAnnotation.swift
+++ b/ElementX/Sources/Other/MapLibre/LocationAnnotation.swift
@@ -7,10 +7,10 @@
//
import Foundation
-import Mapbox
+import MapLibre
import SwiftUI
-final class LocationAnnotation: NSObject, MGLAnnotation {
+final class LocationAnnotation: NSObject, MLNAnnotation {
let coordinate: CLLocationCoordinate2D
let anchorPoint: CGPoint
let view: AnyView
@@ -27,10 +27,10 @@ final class LocationAnnotation: NSObject, MGLAnnotation {
}
}
-final class LocationAnnotationView: MGLUserLocationAnnotationView {
+final class LocationAnnotationView: MLNUserLocationAnnotationView {
// MARK: - Setup
- override init(annotation: MGLAnnotation?, reuseIdentifier: String?) {
+ override init(annotation: MLNAnnotation?, reuseIdentifier: String?) {
super.init(annotation: annotation, reuseIdentifier:
reuseIdentifier)
}
diff --git a/ElementX/Sources/Services/Analytics/PHGPostHogConfiguration.swift b/ElementX/Sources/Services/Analytics/PHGPostHogConfiguration.swift
index 598200f24..9da8a44da 100644
--- a/ElementX/Sources/Services/Analytics/PHGPostHogConfiguration.swift
+++ b/ElementX/Sources/Services/Analytics/PHGPostHogConfiguration.swift
@@ -13,6 +13,7 @@ extension PostHogConfig {
let postHogConfiguration = PostHogConfig(apiKey: analyticsConfiguration.apiKey, host: analyticsConfiguration.host)
// We capture screens manually
postHogConfiguration.captureScreenViews = false
+ postHogConfiguration.surveys = false
return postHogConfiguration
}
diff --git a/ElementX/SupportingFiles/Settings.bundle/Acknowledgements.plist b/ElementX/SupportingFiles/Settings.bundle/Acknowledgements.plist
index d1a011a0f..3b2bda6f4 100644
--- a/ElementX/SupportingFiles/Settings.bundle/Acknowledgements.plist
+++ b/ElementX/SupportingFiles/Settings.bundle/Acknowledgements.plist
@@ -100,9 +100,9 @@
File
- Packages/MapLibre GL Native
+ Packages/MapLibre Native
Title
- MapLibre GL Native
+ MapLibre Native
Type
PSChildPaneSpecifier
@@ -178,6 +178,14 @@
Type
PSChildPaneSpecifier
+
+ File
+ Packages/swift-atomics
+ Title
+ swift-atomics
+ Type
+ PSChildPaneSpecifier
+
File
Packages/swift-clocks
diff --git a/ElementX/SupportingFiles/Settings.bundle/Packages/MapLibre GL Native.plist b/ElementX/SupportingFiles/Settings.bundle/Packages/MapLibre Native.plist
similarity index 100%
rename from ElementX/SupportingFiles/Settings.bundle/Packages/MapLibre GL Native.plist
rename to ElementX/SupportingFiles/Settings.bundle/Packages/MapLibre Native.plist
diff --git a/ElementX/SupportingFiles/Settings.bundle/Packages/swift-atomics.plist b/ElementX/SupportingFiles/Settings.bundle/Packages/swift-atomics.plist
new file mode 100644
index 000000000..182faa6e4
--- /dev/null
+++ b/ElementX/SupportingFiles/Settings.bundle/Packages/swift-atomics.plist
@@ -0,0 +1,226 @@
+
+
+
+
+ PreferenceSpecifiers
+
+
+ FooterText
+ Apache License
+ Version 2.0, January 2004
+ http://www.apache.org/licenses/
+
+ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION
+
+ 1. Definitions.
+
+ "License" shall mean the terms and conditions for use, reproduction,
+ and distribution as defined by Sections 1 through 9 of this document.
+
+ "Licensor" shall mean the copyright owner or entity authorized by
+ the copyright owner that is granting the License.
+
+ "Legal Entity" shall mean the union of the acting entity and all
+ other entities that control, are controlled by, or are under common
+ control with that entity. For the purposes of this definition,
+ "control" means (i) the power, direct or indirect, to cause the
+ direction or management of such entity, whether by contract or
+ otherwise, or (ii) ownership of fifty percent (50%) or more of the
+ outstanding shares, or (iii) beneficial ownership of such entity.
+
+ "You" (or "Your") shall mean an individual or Legal Entity
+ exercising permissions granted by this License.
+
+ "Source" form shall mean the preferred form for making modifications,
+ including but not limited to software source code, documentation
+ source, and configuration files.
+
+ "Object" form shall mean any form resulting from mechanical
+ transformation or translation of a Source form, including but
+ not limited to compiled object code, generated documentation,
+ and conversions to other media types.
+
+ "Work" shall mean the work of authorship, whether in Source or
+ Object form, made available under the License, as indicated by a
+ copyright notice that is included in or attached to the work
+ (an example is provided in the Appendix below).
+
+ "Derivative Works" shall mean any work, whether in Source or Object
+ form, that is based on (or derived from) the Work and for which the
+ editorial revisions, annotations, elaborations, or other modifications
+ represent, as a whole, an original work of authorship. For the purposes
+ of this License, Derivative Works shall not include works that remain
+ separable from, or merely link (or bind by name) to the interfaces of,
+ the Work and Derivative Works thereof.
+
+ "Contribution" shall mean any work of authorship, including
+ the original version of the Work and any modifications or additions
+ to that Work or Derivative Works thereof, that is intentionally
+ submitted to Licensor for inclusion in the Work by the copyright owner
+ or by an individual or Legal Entity authorized to submit on behalf of
+ the copyright owner. For the purposes of this definition, "submitted"
+ means any form of electronic, verbal, or written communication sent
+ to the Licensor or its representatives, including but not limited to
+ communication on electronic mailing lists, source code control systems,
+ and issue tracking systems that are managed by, or on behalf of, the
+ Licensor for the purpose of discussing and improving the Work, but
+ excluding communication that is conspicuously marked or otherwise
+ designated in writing by the copyright owner as "Not a Contribution."
+
+ "Contributor" shall mean Licensor and any individual or Legal Entity
+ on behalf of whom a Contribution has been received by Licensor and
+ subsequently incorporated within the Work.
+
+ 2. Grant of Copyright License. Subject to the terms and conditions of
+ this License, each Contributor hereby grants to You a perpetual,
+ worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+ copyright license to reproduce, prepare Derivative Works of,
+ publicly display, publicly perform, sublicense, and distribute the
+ Work and such Derivative Works in Source or Object form.
+
+ 3. Grant of Patent License. Subject to the terms and conditions of
+ this License, each Contributor hereby grants to You a perpetual,
+ worldwide, non-exclusive, no-charge, royalty-free, irrevocable
+ (except as stated in this section) patent license to make, have made,
+ use, offer to sell, sell, import, and otherwise transfer the Work,
+ where such license applies only to those patent claims licensable
+ by such Contributor that are necessarily infringed by their
+ Contribution(s) alone or by combination of their Contribution(s)
+ with the Work to which such Contribution(s) was submitted. If You
+ institute patent litigation against any entity (including a
+ cross-claim or counterclaim in a lawsuit) alleging that the Work
+ or a Contribution incorporated within the Work constitutes direct
+ or contributory patent infringement, then any patent licenses
+ granted to You under this License for that Work shall terminate
+ as of the date such litigation is filed.
+
+ 4. Redistribution. You may reproduce and distribute copies of the
+ Work or Derivative Works thereof in any medium, with or without
+ modifications, and in Source or Object form, provided that You
+ meet the following conditions:
+
+ (a) You must give any other recipients of the Work or
+ Derivative Works a copy of this License; and
+
+ (b) You must cause any modified files to carry prominent notices
+ stating that You changed the files; and
+
+ (c) You must retain, in the Source form of any Derivative Works
+ that You distribute, all copyright, patent, trademark, and
+ attribution notices from the Source form of the Work,
+ excluding those notices that do not pertain to any part of
+ the Derivative Works; and
+
+ (d) If the Work includes a "NOTICE" text file as part of its
+ distribution, then any Derivative Works that You distribute must
+ include a readable copy of the attribution notices contained
+ within such NOTICE file, excluding those notices that do not
+ pertain to any part of the Derivative Works, in at least one
+ of the following places: within a NOTICE text file distributed
+ as part of the Derivative Works; within the Source form or
+ documentation, if provided along with the Derivative Works; or,
+ within a display generated by the Derivative Works, if and
+ wherever such third-party notices normally appear. The contents
+ of the NOTICE file are for informational purposes only and
+ do not modify the License. You may add Your own attribution
+ notices within Derivative Works that You distribute, alongside
+ or as an addendum to the NOTICE text from the Work, provided
+ that such additional attribution notices cannot be construed
+ as modifying the License.
+
+ You may add Your own copyright statement to Your modifications and
+ may provide additional or different license terms and conditions
+ for use, reproduction, or distribution of Your modifications, or
+ for any such Derivative Works as a whole, provided Your use,
+ reproduction, and distribution of the Work otherwise complies with
+ the conditions stated in this License.
+
+ 5. Submission of Contributions. Unless You explicitly state otherwise,
+ any Contribution intentionally submitted for inclusion in the Work
+ by You to the Licensor shall be under the terms and conditions of
+ this License, without any additional terms or conditions.
+ Notwithstanding the above, nothing herein shall supersede or modify
+ the terms of any separate license agreement you may have executed
+ with Licensor regarding such Contributions.
+
+ 6. Trademarks. This License does not grant permission to use the trade
+ names, trademarks, service marks, or product names of the Licensor,
+ except as required for reasonable and customary use in describing the
+ origin of the Work and reproducing the content of the NOTICE file.
+
+ 7. Disclaimer of Warranty. Unless required by applicable law or
+ agreed to in writing, Licensor provides the Work (and each
+ Contributor provides its Contributions) on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+ implied, including, without limitation, any warranties or conditions
+ of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A
+ PARTICULAR PURPOSE. You are solely responsible for determining the
+ appropriateness of using or redistributing the Work and assume any
+ risks associated with Your exercise of permissions under this License.
+
+ 8. Limitation of Liability. In no event and under no legal theory,
+ whether in tort (including negligence), contract, or otherwise,
+ unless required by applicable law (such as deliberate and grossly
+ negligent acts) or agreed to in writing, shall any Contributor be
+ liable to You for damages, including any direct, indirect, special,
+ incidental, or consequential damages of any character arising as a
+ result of this License or out of the use or inability to use the
+ Work (including but not limited to damages for loss of goodwill,
+ work stoppage, computer failure or malfunction, or any and all
+ other commercial damages or losses), even if such Contributor
+ has been advised of the possibility of such damages.
+
+ 9. Accepting Warranty or Additional Liability. While redistributing
+ the Work or Derivative Works thereof, You may choose to offer,
+ and charge a fee for, acceptance of support, warranty, indemnity,
+ or other liability obligations and/or rights consistent with this
+ License. However, in accepting such obligations, You may act only
+ on Your own behalf and on Your sole responsibility, not on behalf
+ of any other Contributor, and only if You agree to indemnify,
+ defend, and hold each Contributor harmless for any liability
+ incurred by, or claims asserted against, such Contributor by reason
+ of your accepting any such warranty or additional liability.
+
+ END OF TERMS AND CONDITIONS
+
+ APPENDIX: How to apply the Apache License to your work.
+
+ To apply the Apache License to your work, attach the following
+ boilerplate notice, with the fields enclosed by brackets "[]"
+ replaced with your own identifying information. (Don't include
+ the brackets!) The text should be enclosed in the appropriate
+ comment syntax for the file format. We also recommend that a
+ file or class name and description of purpose be included on the
+ same "printed page" as the copyright notice for easier
+ identification within third-party archives.
+
+ Copyright [yyyy] [name of copyright owner]
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+
+
+
+## Runtime Library Exception to the Apache 2.0 License: ##
+
+
+ As an exception, if you use this Software to compile your source code and
+ portions of this Software are embedded into the binary product as a result,
+ you may redistribute such product without providing attribution as would
+ otherwise be required by Sections 4(a), 4(b) and 4(d) of the License.
+
+ Type
+ PSGroupSpecifier
+
+
+
+
diff --git a/ElementX/SupportingFiles/target.yml b/ElementX/SupportingFiles/target.yml
index 4cbc6e24c..3bcf75b05 100644
--- a/ElementX/SupportingFiles/target.yml
+++ b/ElementX/SupportingFiles/target.yml
@@ -236,7 +236,7 @@ targets:
- package: KZFileWatchers
- package: LoremSwiftum
- package: LRUCache
- - package: Mapbox
+ - package: MapLibre
- package: PostHog
- package: SwiftState
- package: GZIP
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-en-GB.png
index cd6190a8e..2b2dbf963 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:360234243b061aa72e37c053e67755fb63a5c60d01b4f90f84ba1bba498134ed
-size 98951
+oid sha256:bc4ac296b7324d7c671f5d9b2d9177503fc65da88ecb2e4ceb448c63b1719d94
+size 98949
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-pseudo.png
index 7892292ba..7d18d9ded 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPad-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:991f11da5c385950c4a47d9bae5aafedcb49b3e6e0cf5c3118d6096e664c25e2
-size 99765
+oid sha256:5436ea7dff07d90938cf0272f031d7ca5ea421492af01210a207635758dd1dea
+size 99763
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-en-GB.png
index aa3a38126..f3521ac96 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:7a4791d5d33bed4fe128e2441b77dc3e3a1d1a624d19729633412a43cb7dbb81
-size 56083
+oid sha256:07352ff97ea1b150f87496cf6b120301d691787b955d00f174f20544d71dfd6c
+size 56086
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-pseudo.png
index c9d96a156..f328c5418 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/composerToolbar.Voice-Message-iPhone-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:c59b1ca32c64bbc046cc61cac6644d0d2272569425fb8f0e5cdd8dad9068d1d1
-size 56917
+oid sha256:c261a9f1e2f89bb4e4dc05dddb0841c43b78741ca2035ade2f8b23c411c3ab3c
+size 56920
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-en-GB.png
index 667bfabd5..6c8179284 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:8de305dd38931f0a9d673f7565ec9d01313ad90f0d8b2d92642bb348c5c85cf6
-size 92039
+oid sha256:7fe3be6ac7144e77a64deea2ec9abe990b7066df18bf693018e3cbbac95f7b19
+size 92909
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-pseudo.png
index 5d079f6be..99956db47 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPad-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:385e54561312688b66f26fbfe7d1e75af8cd7663950b9cd7e6b787e6055e5d7a
-size 93610
+oid sha256:29136dedce23b9175a539c68f190f339972cfeedd51714b2d7dbcd487c0918c1
+size 94512
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-en-GB.png
index e5de93e06..9822eecfc 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:8a7967b4339626d67c58124a12f2fc300460ccf5f99be941e04e305ee58f64d2
-size 46876
+oid sha256:dd7467f8fecb694a44d88e404999373428dd5b0909f9a821a8cbc9961f132b59
+size 46905
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-pseudo.png
index b51fbe890..086a0b733 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.Picker-iPhone-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:3f1b5f3a578b2b7f7317cffcbf791091ad21a8206457405122369675cfcc17de
-size 48094
+oid sha256:c3cd2e0746b0f78394304c614d9a80cd15392986a58b4b64eaa36757997aff42
+size 48123
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-en-GB.png
index 9f756d822..8389bc0fa 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:d4d00ba930b8f85c4d6770dc8c3586844cf2180ff2e830c9bd6a0587b7cdc45e
-size 87527
+oid sha256:1fed42a97d568cc0d024afb9be2c7c8ae2359a88f1335b307ab5b8cbe0929f59
+size 88451
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-pseudo.png
index 5b8a67635..b7b557abe 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPad-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:8d8bf5616b74a7fcc2ae7a567affe8c6517eeacab1562550bb614ab41305b55f
-size 87888
+oid sha256:79e7bdc97b95baf9ec65240a09543d1efa7a6f0ee8178a0ad24ec7fa25f4fbcf
+size 88813
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-en-GB.png
index e49c55375..83b007d71 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:db096b8d42be9426bf2f1e0e7948a507f7208bca6c44abfec7d6e2d4434491c6
-size 42243
+oid sha256:8dc6d6f2dcdac244d56349c4d432e43c281e539a83769e4711ebfa43d5b62462
+size 42173
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-pseudo.png
index e49c55375..83b007d71 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-iPhone-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:db096b8d42be9426bf2f1e0e7948a507f7208bca6c44abfec7d6e2d4434491c6
-size 42243
+oid sha256:8dc6d6f2dcdac244d56349c4d432e43c281e539a83769e4711ebfa43d5b62462
+size 42173
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-en-GB.png
index cfd8af90c..0a947c5cf 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:c5aef10d5191f8e67103f83351ac9e7eb42e1557b60ca4f235adacbe2f720be6
-size 90605
+oid sha256:3ec7064466b5a91fd490c9aebdcfb36efbc2a585b86998725bcd90e2c280c726
+size 91675
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-pseudo.png
index 4d58d906d..41496ee0f 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPad-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:7ad30efb39751421aa4260e5a99acebbe98ed7a1f857b296a46c26a046a48ff9
-size 90983
+oid sha256:241dd732058072774947a9aa0dbd7c6bf410608ba8b4e1733942161feb7d725e
+size 92048
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-en-GB.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-en-GB.png
index 2b37ecb7f..b0f360a38 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-en-GB.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-en-GB.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:29aa8fccd4b005e9df48a630a28123c1dbd87e20532bb06ae8bc098c15f7bcb0
-size 45148
+oid sha256:763523520732699428fcf758b36119ff450d13b6f69b250e5c977651ae06d05e
+size 45091
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-pseudo.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-pseudo.png
index 2b37ecb7f..b0f360a38 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-pseudo.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/staticLocationScreenViewer.View-Only-with-description-iPhone-pseudo.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:29aa8fccd4b005e9df48a630a28123c1dbd87e20532bb06ae8bc098c15f7bcb0
-size 45148
+oid sha256:763523520732699428fcf758b36119ff450d13b6f69b250e5c977651ae06d05e
+size 45091
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-en-GB-0.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-en-GB-0.png
index 6c40bc49d..131d69697 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-en-GB-0.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-en-GB-0.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:641bf4dd2d18f7ff9f72d9aadf574fc276deda99525cd6c933506043c60a6856
-size 71904
+oid sha256:e73905b33bd46b40b2872ee378b04c30f1be789e0deb5e3bd5cde165b282b46d
+size 71895
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-pseudo-0.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-pseudo-0.png
index 6c40bc49d..131d69697 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-pseudo-0.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPad-pseudo-0.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:641bf4dd2d18f7ff9f72d9aadf574fc276deda99525cd6c933506043c60a6856
-size 71904
+oid sha256:e73905b33bd46b40b2872ee378b04c30f1be789e0deb5e3bd5cde165b282b46d
+size 71895
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-en-GB-0.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-en-GB-0.png
index 7de434124..dd160140c 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-en-GB-0.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-en-GB-0.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:31b749bf22b17db53d6a0128b366a73238ee89e7593c71c445e911608835a588
-size 31069
+oid sha256:ff0e48c5fe7c8a0f6bcbf9971a6142f625f13908c6d7bf45f2beaed4b501eba0
+size 31089
diff --git a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-pseudo-0.png b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-pseudo-0.png
index 7de434124..dd160140c 100644
--- a/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-pseudo-0.png
+++ b/PreviewTests/Sources/__Snapshots__/PreviewTests/voiceMessagePreviewComposer.iPhone-pseudo-0.png
@@ -1,3 +1,3 @@
version https://git-lfs.github.com/spec/v1
-oid sha256:31b749bf22b17db53d6a0128b366a73238ee89e7593c71c445e911608835a588
-size 31069
+oid sha256:ff0e48c5fe7c8a0f6bcbf9971a6142f625f13908c6d7bf45f2beaed4b501eba0
+size 31089
diff --git a/compound-ios/Package.resolved b/compound-ios/Package.resolved
index ebf181668..1437e004a 100644
--- a/compound-ios/Package.resolved
+++ b/compound-ios/Package.resolved
@@ -32,8 +32,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/pointfreeco/swift-snapshot-testing",
"state" : {
- "revision" : "1be8144023c367c5de701a6313ed29a3a10bf59b",
- "version" : "1.18.3"
+ "revision" : "a8b7c5e0ed33d8ab8887d1654d9b59f2cbad529b",
+ "version" : "1.18.7"
}
},
{
@@ -41,8 +41,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/swiftlang/swift-syntax",
"state" : {
- "revision" : "f99ae8aa18f0cf0d53481901f88a0991dc3bd4a2",
- "version" : "601.0.1"
+ "revision" : "4799286537280063c85a32f09884cfbca301b1a1",
+ "version" : "602.0.0"
}
},
{
@@ -59,8 +59,8 @@
"kind" : "remoteSourceControl",
"location" : "https://github.com/pointfreeco/xctest-dynamic-overlay",
"state" : {
- "revision" : "b2ed9eabefe56202ee4939dd9fc46b6241c88317",
- "version" : "1.6.1"
+ "revision" : "34e463e98ab8541c604af706c99bed7160f5ec70",
+ "version" : "1.8.1"
}
}
],
diff --git a/compound-ios/Package.swift b/compound-ios/Package.swift
index e3969a7c7..d3e020f37 100644
--- a/compound-ios/Package.swift
+++ b/compound-ios/Package.swift
@@ -13,7 +13,7 @@ let package = Package(
// .package(path: "../compound-design-tokens"),
.package(url: "https://github.com/siteline/SwiftUI-Introspect", from: "26.0.0"),
.package(url: "https://github.com/SFSafeSymbols/SFSafeSymbols", from: "7.0.0"),
- .package(url: "https://github.com/pointfreeco/swift-snapshot-testing", exact: "1.18.3")
+ .package(url: "https://github.com/pointfreeco/swift-snapshot-testing", exact: "1.18.7")
],
targets: [
.target(
diff --git a/project.yml b/project.yml
index 36b056701..4753e5e3e 100644
--- a/project.yml
+++ b/project.yml
@@ -79,14 +79,14 @@ packages:
path: compound-ios
AnalyticsEvents:
url: https://github.com/matrix-org/matrix-analytics-events
- minorVersion: 0.29.2
+ minorVersion: 0.30.0
# path: ../matrix-analytics-events
EmbeddedElementCall:
url: https://github.com/element-hq/element-call-swift
- exactVersion: 0.16.0-rc.4
+ exactVersion: 0.16.3
Emojibase:
url: https://github.com/matrix-org/emojibase-bindings
- minorVersion: 1.4.2
+ minorVersion: 1.5.0
# path: ../emojibase-bindings
SwiftOGG:
url: https://github.com/element-hq/swift-ogg
@@ -103,19 +103,19 @@ packages:
minorVersion: 1.2.1
AsyncAlgorithms:
url: https://github.com/apple/swift-async-algorithms
- minorVersion: 1.0.0
+ minorVersion: 1.1.1
Clocks:
url: https://github.com/pointfreeco/swift-clocks
from: 1.0.6
Collections:
url: https://github.com/apple/swift-collections
- minorVersion: 1.2.0
+ minorVersion: 1.3.0
DeviceKit:
url: https://github.com/devicekit/DeviceKit
- minorVersion: 5.6.0
+ minorVersion: 5.7.0
DSWaveformImage:
url: https://github.com/dmrschmidt/DSWaveformImage
- exactVersion: 14.1.1
+ exactVersion: 14.2.2
Dynamic:
url: https://github.com/mhdhejazi/Dynamic
exactVersion: 1.2
@@ -127,31 +127,31 @@ packages:
minorVersion: 4.2.2
Kingfisher:
url: https://github.com/onevcat/Kingfisher
- minorVersion: 8.3.2
+ minorVersion: 8.6.2
KZFileWatchers:
url: https://github.com/krzysztofzablocki/KZFileWatchers
minorVersion: 1.2.0
LoremSwiftum:
url: https://github.com/lukaskubanek/LoremSwiftum
- minorVersion: 2.2.1
+ minorVersion: 2.2.3
LRUCache:
url: https://github.com/nicklockwood/LRUCache
- minorVersion: 1.0.4
- Mapbox:
+ minorVersion: 1.2.0
+ MapLibre:
url: https://github.com/maplibre/maplibre-gl-native-distribution
- minorVersion: 5.13.0
+ minorVersion: 6.22.1
PostHog:
url: https://github.com/PostHog/posthog-ios
- minorVersion: 3.27.0
+ minorVersion: 3.37.1
Sentry:
url: https://github.com/getsentry/sentry-cocoa
- minorVersion: 8.52.1
+ minorVersion: 9.1.0
SnapshotTesting:
url: https://github.com/pointfreeco/swift-snapshot-testing
- minorVersion: 1.18.3
+ minorVersion: 1.18.7
SwiftSoup:
url: https://github.com/scinfu/SwiftSoup.git
- minorVersion: 2.8.8
+ minorVersion: 2.11.2
SwiftState:
url: https://github.com/ReactKit/SwiftState
minorVersion: 6.0.0
diff --git a/ElementX/Sources/Other/MapLibre/MapLibreMapView.swift b/ElementX/Sources/Other/MapLibre/MapLibreMapView.swift
index 510b55499..478598c05 100644
--- a/ElementX/Sources/Other/MapLibre/MapLibreMapView.swift
+++ b/ElementX/Sources/Other/MapLibre/MapLibreMapView.swift
@@ -7,7 +7,7 @@
//
import Combine
-import Mapbox
+import MapLibre
import SwiftUI
struct MapLibreMapView: UIViewRepresentable {
@@ -54,14 +54,14 @@ struct MapLibreMapView: UIViewRepresentable {
// MARK: - UIViewRepresentable
- func makeUIView(context: Context) -> MGLMapView {
+ func makeUIView(context: Context) -> MLNMapView {
let mapView = makeMapView()
mapView.delegate = context.coordinator
setupMap(mapView: mapView, with: options)
return mapView
}
- func updateUIView(_ mapView: MGLMapView, context: Context) {
+ func updateUIView(_ mapView: MLNMapView, context: Context) {
// Don't set the same value twice. Otherwise, if there is an error loading the map, a loop
// is caused as the `error` binding being set, which triggers this update, which sets a
// new URL, which causes another error, and so it goes on round and round in a circle.
@@ -79,14 +79,14 @@ struct MapLibreMapView: UIViewRepresentable {
// MARK: - Private
- private func setupMap(mapView: MGLMapView, with options: Options) {
+ private func setupMap(mapView: MLNMapView, with options: Options) {
mapView.addAnnotations(options.annotations)
mapView.zoomLevel = options.annotations.isEmpty ? options.initialZoomLevel : options.zoomLevel
mapView.centerCoordinate = options.mapCenter
}
- private func makeMapView() -> MGLMapView {
- let mapView = MGLMapView(frame: .zero, styleURL: mapURLBuilder.interactiveMapURL(for: colorScheme == .dark ? .dark : .light))
+ private func makeMapView() -> MLNMapView {
+ let mapView = MLNMapView(frame: .zero, styleURL: mapURLBuilder.interactiveMapURL(for: colorScheme == .dark ? .dark : .light))
mapView.logoViewPosition = .topLeft
mapView.attributionButtonPosition = .topLeft
mapView.attributionButtonMargins = .init(x: mapView.logoView.frame.maxX + 8, y: mapView.logoView.center.y / 2)
@@ -96,7 +96,7 @@ struct MapLibreMapView: UIViewRepresentable {
return mapView
}
- private func showUserLocation(in mapView: MGLMapView) {
+ private func showUserLocation(in mapView: MLNMapView) {
switch (showsUserLocationMode, options.annotations) {
case (.showAndFollow, _):
mapView.userTrackingMode = .follow
@@ -119,12 +119,12 @@ struct MapLibreMapView: UIViewRepresentable {
// MARK: - Coordinator
extension MapLibreMapView {
- class Coordinator: NSObject, MGLMapViewDelegate {
+ class Coordinator: NSObject, MLNMapViewDelegate {
// MARK: - Properties
var mapLibreView: MapLibreMapView
- private var previousUserLocation: MGLUserLocation?
+ private var previousUserLocation: MLNUserLocation?
// MARK: - Setup
@@ -132,22 +132,22 @@ extension MapLibreMapView {
self.mapLibreView = mapLibreView
}
- // MARK: - MGLMapViewDelegate
+ // MARK: - MLNMapViewDelegate
- func mapView(_ mapView: MGLMapView, viewFor annotation: MGLAnnotation) -> MGLAnnotationView? {
+ func mapView(_ mapView: MLNMapView, viewFor annotation: MLNAnnotation) -> MLNAnnotationView? {
guard let annotation = annotation as? LocationAnnotation else {
return nil
}
return LocationAnnotationView(annotation: annotation)
}
- func mapViewDidFailLoadingMap(_ mapView: MGLMapView, withError error: Error) {
+ func mapViewDidFailLoadingMap(_ mapView: MLNMapView, withError error: Error) {
if mapLibreView.error != .failedLoadingMap {
mapLibreView.error = .failedLoadingMap
}
}
- func mapView(_ mapView: MGLMapView, didUpdate userLocation: MGLUserLocation?) {
+ func mapView(_ mapView: MLNMapView, didUpdate userLocation: MLNUserLocation?) {
guard let userLocation else { return }
if previousUserLocation == nil, mapLibreView.options.annotations.isEmpty {
@@ -160,7 +160,7 @@ extension MapLibreMapView {
updateGeolocationUncertainty(location: userLocation)
}
- func mapView(_ mapView: MGLMapView, didChangeLocationManagerAuthorization manager: MGLLocationManager) {
+ func mapView(_ mapView: MLNMapView, didChangeLocationManagerAuthorization manager: MLNLocationManager) {
switch manager.authorizationStatus {
case .denied, .restricted:
mapLibreView.isLocationAuthorized = false
@@ -173,14 +173,14 @@ extension MapLibreMapView {
}
}
- func mapView(_ mapView: MGLMapView, regionDidChangeAnimated animated: Bool) {
+ func mapView(_ mapView: MLNMapView, regionDidChangeAnimated animated: Bool) {
// Avoid `Publishing changes from within view update` warnings
DispatchQueue.main.async { [mapLibreView] in
mapLibreView.mapCenterCoordinate = mapView.centerCoordinate
}
}
- func mapView(_ mapView: MGLMapView, shouldChangeFrom oldCamera: MGLMapCamera, to newCamera: MGLMapCamera, reason: MGLCameraChangeReason) -> Bool {
+ func mapView(_ mapView: MLNMapView, shouldChangeFrom oldCamera: MLNMapCamera, to newCamera: MLNMapCamera, reason: MLNCameraChangeReason) -> Bool {
// we send the userDidPan event only for the reasons that actually will change the map center, and not zoom only / rotations only events.
switch reason {
case .gesturePan,
@@ -203,13 +203,13 @@ extension MapLibreMapView {
// MARK: Callout
- func mapView(_ mapView: MGLMapView, annotationCanShowCallout annotation: MGLAnnotation) -> Bool {
+ func mapView(_ mapView: MLNMapView, annotationCanShowCallout annotation: MLNAnnotation) -> Bool {
false
}
// MARK: Private
- private func updateGeolocationUncertainty(location: MGLUserLocation) {
+ private func updateGeolocationUncertainty(location: MLNUserLocation) {
guard let clLocation = location.location, clLocation.horizontalAccuracy >= 0 else {
mapLibreView.geolocationUncertainty = nil
return
@@ -220,7 +220,7 @@ extension MapLibreMapView {
}
}
// MARK: - MGLMapView convenient methods
private extension MapTilerStyle {
init(_ colorScheme: ColorScheme) {
@@ -220,7 +220,7 @@ extension MapLibreMapView {
}
}
-// MARK: - MGLMapView convenient methods
+// MARK: - MLNMapView convenient methods
private extension MapTilerStyle {
init(_ colorScheme: ColorScheme) {